pub struct LocalStorage;Trait Implementations
Sourceimpl Clone for LocalStorage
impl Clone for LocalStorage
Sourcefn clone(&self) -> LocalStorage
fn clone(&self) -> LocalStorage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl StorageBacking for LocalStorage
impl StorageBacking for LocalStorage
Sourceimpl StorageSubscriber<LocalStorage> for LocalStorage
impl StorageSubscriber<LocalStorage> for LocalStorage
Sourcefn subscribe<T: DeserializeOwned + Send + Sync + Clone + 'static>(
key: &<LocalStorage as StorageBacking>::Key,
) -> Receiver<StorageChannelPayload>
fn subscribe<T: DeserializeOwned + Send + Sync + Clone + 'static>( key: &<LocalStorage as StorageBacking>::Key, ) -> Receiver<StorageChannelPayload>
Subscribes to events from a storage backing for the given key
Sourcefn unsubscribe(key: &<LocalStorage as StorageBacking>::Key)
fn unsubscribe(key: &<LocalStorage as StorageBacking>::Key)
Unsubscribes from events from a storage backing for the given key